@@ -1,11 +1,10 @@
 
-
 class PDFMargin(object):
 
     def __init__(self, left=20, top=None, right=None, bottom=None):
         self.set(left, top, right, bottom)
 
-    def set(self, left, top=None, right=None, bottom=None):
+    def set(self, left, top, right, bottom):
         self.left = left
         if top is None:
             top = left
